package com.company.changes.screen.newentity;

import com.company.changes.entity.NewEntity;
import io.jmix.core.DataManager;
import io.jmix.ui.Notifications;
import io.jmix.ui.action.Action;
import io.jmix.ui.model.CollectionContainer;
import io.jmix.ui.model.InstanceContainer;
import io.jmix.ui.screen.*;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;

import java.util.ArrayList;
import java.util.List;

@UiController("NewEntity.browse")
@UiDescriptor("new-entity-browse.xml")
@LookupComponent("newEntitiesTable")
public class NewEntityBrowse extends StandardLookup<NewEntity> {
    private static final Logger log = LoggerFactory.getLogger(NewEntityBrowse.class);

    @Autowired
    protected DataManager dataManager;
    @Autowired
    protected CollectionContainer<NewEntity> newEntitiesDc;
    @Autowired
    protected Notifications notifications;

    @Subscribe("newEntitiesTable.refresh")
    protected void onNewEntitiesTableRefresh(final Action.ActionPerformedEvent event) {
        newEntitiesDc.getMutableItems().clear();
        newEntitiesDc.getMutableItems().addAll(initDc());
    }

    @Subscribe
    protected void onBeforeShow(final BeforeShowEvent event) {
        newEntitiesDc.getMutableItems().addAll(initDc());
    }

    private List<NewEntity> initDc() {
        List<NewEntity> list = new ArrayList<>();
        for (int i = 0; i < 50; i++) {
            NewEntity entity = dataManager.create(NewEntity.class);
            entity.setName("name " + i);
            list.add(entity);
        }
        return list;
    }

    @Subscribe(id = "newEntitiesDc", target = Target.DATA_CONTAINER)
    protected void onNewEntitiesDcItemPropertyChange(final InstanceContainer.ItemPropertyChangeEvent<NewEntity> event) {
        log.info("##-------## onNewEntitiesDcItemPropertyChange");
        notifications.create().withDescription("onNewEntitiesDcItemPropertyChange").show();
    }

    @Subscribe(id = "newEntitiesDc", target = Target.DATA_CONTAINER)
    protected void onNewEntitiesDcCollectionChange(final CollectionContainer.CollectionChangeEvent<NewEntity> event) {
        log.info("###### onNewEntitiesDcCollectionChange");
    }

    @Subscribe(id = "newEntitiesDc", target = Target.DATA_CONTAINER)
    protected void onNewEntitiesDcItemChange(final InstanceContainer.ItemChangeEvent<NewEntity> event) {
        log.info("###### onNewEntitiesDcItemChange");

    }
}